<?php
/**
 * Theme functions: init, enqueue scripts and styles, include required files and widgets
 *
 * @package WordPress
 * @subpackage BASIL
 * @since BASIL 1.0
 */

// Theme storage
$BASIL_STORAGE = array(
	// Theme required plugin's slugs
	'required_plugins' => array(

		// Required plugins
		// DON'T COMMENT OR REMOVE NEXT LINES!
		'trx_addons',
		// Recommended (supported) plugins
		// If plugin not need - comment (or remove) it
		'essential-grid',
		'trx_socials',
		'js_composer',
		'mailchimp-for-wp',
		'revslider',
		'woocommerce',
        'contact-form-7',
        'trx_updater',
        'elegro-payment',
		'instagram-feed'
		)
	);




/**
 * Fire the wp_body_open action.
 *
 * Added for backwards compatibility to support pre 5.2.0 WordPress versions.
 */
if ( ! function_exists( 'wp_body_open' ) ) {
    function wp_body_open() {
        /**
         * Triggered after the opening <body> tag.
         */
        do_action('wp_body_open');
    }
}



//-------------------------------------------------------
//-- Theme init
//-------------------------------------------------------

// Theme init priorities:
// 1 - register filters to add/remove lists items in the Theme Options
// 2 - create Theme Options
// 3 - add/remove Theme Options elements
// 5 - load Theme Options
// 9 - register other filters (for installer, etc.)
//10 - standard Theme init procedures (not ordered)

if ( !function_exists('basil_theme_setup1') ) {
	add_action( 'after_setup_theme', 'basil_theme_setup1', 1 );
	function basil_theme_setup1() {
// Set theme content width
		$GLOBALS['content_width'] = apply_filters( 'basil_filter_content_width', 1170 );
	}
}

if ( !function_exists('basil_theme_setup') ) {
	add_action( 'after_setup_theme', 'basil_theme_setup' );
	function basil_theme_setup() {

// Add default posts and comments RSS feed links to head 
		add_theme_support( 'automatic-feed-links' );

// Enable support for Post Thumbnails
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size(370, 0, false);

// Add thumb sizes
// ATTENTION! If you change list below - check filter's names in the 'trx_addons_filter_get_thumb_size' hook
		$thumb_sizes = apply_filters('basil_filter_add_thumb_sizes', array(
			'basil-thumb-huge'		=> array(1170, 658, true),
            'basil-thumb-big' 		=> array( 1540, 872, true),
			'basil-thumb-med' 		=> array( 555, 312, true),
			'basil-thumb-courses' 	=> array( 555, 399, true),
			'basil-thumb-team' 		=> array( 755, 817, true),
			'basil-thumb-squarebig' 	=> array( 555, 453, true),
			'basil-thumb-tiny' 		=> array(  90,  90, true),
'basil-thumb-masonry-big' => array( 770,   0, false),		// Only downscale, not crop
'basil-thumb-masonry'		=> array( 370,   0, false),		// Only downscale, not crop
)
		);
		$mult = basil_get_theme_option('retina_ready', 1);
		if ($mult > 1) $GLOBALS['content_width'] = apply_filters( 'basil_filter_content_width', 1170*$mult);
		foreach ($thumb_sizes as $k=>$v) {
// Add Original dimensions
			add_image_size( $k, $v[0], $v[1], $v[2]);
// Add Retina dimensions
			if ($mult > 1) add_image_size( $k.'-@retina', $v[0]*$mult, $v[1]*$mult, $v[2]);
		}

// Custom header setup
		add_theme_support( 'custom-header', array(
			'header-text'=>false
			)
		);

// Custom backgrounds setup
		add_theme_support( 'custom-background', array()	);

// Supported posts formats
		add_theme_support( 'post-formats', array('gallery', 'video', 'audio', 'link', 'quote', 'image', 'status', 'aside', 'chat') ); 

// Autogenerate title tag
		add_theme_support('title-tag');

// Add theme menus
		add_theme_support('nav-menus');

// Switch default markup for search form, comment form, and comments to output valid HTML5.
		add_theme_support( 'html5', array('search-form', 'comment-form', 'comment-list', 'gallery', 'caption') );

// WooCommerce Support
		add_theme_support( 'woocommerce' );

        // Next setting from the WooCommerce 3.0+ enable built-in image zoom on the single product page
        add_theme_support( 'wc-product-gallery-zoom' );

        // Next setting from the WooCommerce 3.0+ enable built-in image slider on the single product page
        add_theme_support( 'wc-product-gallery-slider' );

        // Next setting from the WooCommerce 3.0+ enable built-in image lightbox on the single product page
        add_theme_support( 'wc-product-gallery-lightbox' );


// Editor custom stylesheet - for user
		add_editor_style( array_merge(
			array(
				'css/editor-style.css',
				basil_get_file_url('css/fontello/css/fontello-embedded.css')
				),
			basil_theme_fonts_for_editor()
			)
		);	

// Make theme available for translation
// Translations can be filed in the /languages/ directory
		load_theme_textdomain( 'basil', basil_get_folder_dir('languages') );

// Register navigation menu
		register_nav_menus(array(
			'menu_main' => esc_html__('Main Menu', 'basil'),
			'menu_mobile' => esc_html__('Mobile Menu', 'basil'),
			'menu_footer' => esc_html__('Footer Menu', 'basil')
			)
		);

// Excerpt filters
		add_filter( 'excerpt_length',						'basil_excerpt_length' );
		add_filter( 'excerpt_more',							'basil_excerpt_more' );

// Add required meta tags in the head
		add_action('wp_head',		 						'basil_wp_head', 1);

// Add custom inline styles
		add_action('wp_footer',		 						'basil_wp_footer');
		add_action('admin_footer',	 						'basil_wp_footer');

// Enqueue scripts and styles for frontend
add_action('wp_enqueue_scripts', 					'basil_wp_scripts', 1000);			//priority 1000 - load styles before the plugin's support custom styles (priority 1100)
add_action('wp_footer',		 						'basil_localize_scripts');
add_action('wp_enqueue_scripts', 					'basil_wp_scripts_responsive', 2000);	//priority 2000 - load responsive after all other styles

// Add body classes
add_filter( 'body_class',							'basil_add_body_classes' );

// Register sidebars
add_action('widgets_init',							'basil_register_sidebars');

// Set options for importer (before other plugins)
add_filter( 'trx_addons_filter_importer_options',	'basil_importer_set_options', 9 );
}

}


//-------------------------------------------------------
//-- Thumb sizes
//-------------------------------------------------------
if ( !function_exists('basil_image_sizes') ) {
	add_filter( 'image_size_names_choose', 'basil_image_sizes' );
	function basil_image_sizes( $sizes ) {
		$thumb_sizes = apply_filters('basil_filter_add_thumb_sizes', array(
			'basil-thumb-huge'		=> esc_html__( 'Fullsize image', 'basil' ),
			'basil-thumb-big'			=> esc_html__( 'Large image', 'basil' ),
			'basil-thumb-med'			=> esc_html__( 'Medium image', 'basil' ),
			'basil-thumb-courses'		=> esc_html__( 'Course image', 'basil' ),
			'basil-thumb-team'		=> esc_html__( 'Team image', 'basil' ),
			'basil-thumb-squarebig'	=> esc_html__( 'Square image', 'basil' ),
			'basil-thumb-tiny'		=> esc_html__( 'Small square avatar', 'basil' ),
			'basil-thumb-masonry-big'	=> esc_html__( 'Masonry Large (scaled)', 'basil' ),
			'basil-thumb-masonry'		=> esc_html__( 'Masonry (scaled)', 'basil' ),
			)
		);
		$mult = basil_get_theme_option('retina_ready', 1);
		foreach($thumb_sizes as $k=>$v) {
			$sizes[$k] = $v;
			if ($mult > 1) $sizes[$k.'-@retina'] = $v.' '.esc_html__('@2x', 'basil' );
		}
		return $sizes;
	}
}


//-------------------------------------------------------
//-- Theme scripts and styles
//-------------------------------------------------------

// Load frontend scripts
if ( !function_exists( 'basil_wp_scripts' ) ) {
	function basil_wp_scripts() {

// Enqueue styles
//------------------------

// Links to selected fonts
		$links = basil_theme_fonts_links();
		if (count($links) > 0) {
			foreach ($links as $slug => $link) {
				wp_enqueue_style( sprintf('basil-font-%s', $slug), $link );
			}
		}



// Fontello styles must be loaded before main stylesheet
// This style NEED the theme prefix, because style 'fontello' in some plugin contain different set of characters
// and can't be used instead this style!
		wp_enqueue_style( 'fontello-icons',  basil_get_file_url('css/fontello/css/fontello-embedded.css') );

	// Merged styles
	if ( basil_is_off(basil_get_theme_option('debug_mode')) )
		wp_enqueue_style( 'basil-styles', basil_get_file_url('css/__styles.css') );

// Load main stylesheet
		$main_stylesheet = get_template_directory_uri() . '/style.css';
		wp_enqueue_style( 'basil-main', $main_stylesheet, array(), null );

// Load child stylesheet (if different) after the main stylesheet and fontello icons (important!)
		$child_stylesheet = get_stylesheet_directory_uri() . '/style.css';
		if ($child_stylesheet != $main_stylesheet) {
			wp_enqueue_style( 'basil-child', $child_stylesheet, array('basil-main'), null );
		}

// Add custom bg image for the body_style == 'boxed'
		if ( basil_get_theme_option('body_style') == 'boxed' && ($bg_image = basil_get_theme_option('boxed_bg_image')) != '' )
			wp_add_inline_style( 'basil-main', '.body_style_boxed { background-image:url('.esc_url($bg_image).') }' );

// Custom colors
		if ( !is_customize_preview() && !isset($_GET['color_scheme']) && basil_is_off(basil_get_theme_option('debug_mode')) )
			wp_enqueue_style( 'basil-colors', basil_get_file_url('css/__colors.css') );
		else
			wp_add_inline_style( 'basil-main', basil_customizer_get_css() );



// Add post nav background
		basil_add_bg_in_post_nav();

// Disable loading JQuery UI CSS
		wp_deregister_style('jquery_ui');
		wp_deregister_style('date-picker-css');


// Enqueue scripts	
//------------------------

// Modernizr will load in head before other scripts and styles
		if ( substr(basil_get_theme_option('blog_style'), 0, 7) == 'gallery' || substr(basil_get_theme_option('blog_style'), 0, 9) == 'portfolio' )
			wp_enqueue_script( 'modernizr', basil_get_file_url('js/theme.gallery/modernizr.min.js'), array(), null, false );

// Superfish Menu
// Attention! To prevent duplicate this script in the plugin and in the menu, don't merge it!
		wp_enqueue_script( 'superfish', basil_get_file_url('js/superfish.js'), array('jquery'), null, true );

// Merged scripts
		if ( basil_is_off(basil_get_theme_option('debug_mode')) )
			wp_enqueue_script( 'basil-init', basil_get_file_url('js/__scripts.js'), array('jquery'), null, true );
		else {
// Skip link focus
			wp_enqueue_script( 'skip-link-focus-fix', basil_get_file_url('js/skip-link-focus-fix.js'), null, true );
// Background video
			$header_video = basil_get_theme_option('header_video');
			if (!empty($header_video) && !basil_is_inherit($header_video))
				wp_enqueue_script( 'bideo', basil_get_file_url('js/bideo.js'), array(), null, true );
// Theme scripts
			wp_enqueue_script( 'basil-utils', basil_get_file_url('js/_utils.js'), array('jquery'), null, true );
			wp_enqueue_script( 'basil-init', basil_get_file_url('js/_init.js'), array('jquery'), null, true );	
		}

// Comments
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

// Media elements library	
		if (basil_get_theme_setting('use_mediaelements')) {
			wp_enqueue_style ( 'mediaelement' );
			wp_enqueue_style ( 'wp-mediaelement' );
			wp_enqueue_script( 'mediaelement' );
			wp_enqueue_script( 'wp-mediaelement' );
		}
	}
}

// Add variables to the scripts in the frontend
if ( !function_exists( 'basil_localize_scripts' ) ) {
	function basil_localize_scripts() {
		wp_localize_script( 'basil-init', 'BASIL_STORAGE', apply_filters( 'basil_filter_localize_script', array(
// AJAX parameters
			'ajax_url' => esc_url(admin_url('admin-ajax.php')),
			'ajax_nonce' => esc_attr(wp_create_nonce(admin_url('admin-ajax.php'))),

// Site base url
			'site_url' => get_site_url(),

// User logged in
			'user_logged_in' => is_user_logged_in() ? true : false,

// Window width to switch the site header to the mobile layout
			'mobile_layout_width' => 767,

// Video background
			'background_video' => basil_get_theme_option('header_video'),

// Video and Audio tag wrapper
			'use_mediaelements' => basil_get_theme_setting('use_mediaelements') ? true : false,

// Messages max length
			'message_maxlength'	=> intval(basil_get_theme_setting('message_maxlength')),

// Site color scheme
			'site_scheme' => sprintf('scheme_%s', basil_get_theme_option('color_scheme')),


// Internal vars - do not change it!

// Flag for review mechanism
			'admin_mode' => false,

// E-mail mask
			'email_mask' => '^([a-zA-Z0-9_\\-]+\\.)*[a-zA-Z0-9_\\-]+@[a-z0-9_\\-]+(\\.[a-z0-9_\\-]+)*\\.[a-z]{2,6}$',

// Strings for translation
			'strings' => array(
				'ajax_error'		=> esc_html__('Invalid server answer!', 'basil'),
				'error_global'		=> esc_html__('Error data validation!', 'basil'),
				'name_empty' 		=> esc_html__("The name can't be empty", 'basil'),
				'name_long'			=> esc_html__('Too long name', 'basil'),
				'email_empty'		=> esc_html__('Too short (or empty) email address', 'basil'),
				'email_long'		=> esc_html__('Too long email address', 'basil'),
				'email_not_valid'	=> esc_html__('Invalid email address', 'basil'),
				'text_empty'		=> esc_html__("The message text can't be empty", 'basil'),
				'text_long'			=> esc_html__('Too long message text', 'basil')
				)
			))
		);
	}
}

// Load responsive styles (priority 2000 - load it after main styles and plugins custom styles)
if ( !function_exists( 'basil_wp_scripts_responsive' ) ) {
	function basil_wp_scripts_responsive() {
		wp_enqueue_style( 'basil-responsive', basil_get_file_url('css/responsive.css') );
	}
}

//  Add meta tags and inline scripts in the header for frontend
if (!function_exists('basil_wp_head')) {
	function basil_wp_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="format-detection" content="telephone=no">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
		<link rel="profile" href="//gmpg.org/xfn/11">
		<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
		<?php
	}
}

// Add theme specified classes to the body
if ( !function_exists('basil_add_body_classes') ) {
	function basil_add_body_classes( $classes ) {
		$classes[] = 'body_tag';	// Need for the .scheme_self
		$classes[] = 'scheme_' . esc_attr(basil_get_theme_option('color_scheme'));

		$blog_mode = basil_storage_get('blog_mode');
		$classes[] = 'blog_mode_' . esc_attr($blog_mode);
		$classes[] = 'body_style_' . esc_attr(basil_get_theme_option('body_style'));

		if (in_array($blog_mode, array('post', 'page'))) {
			$classes[] = 'is_single';
		} else {
			$classes[] = ' is_stream';
			$classes[] = 'blog_style_'.esc_attr(basil_get_theme_option('blog_style'));
			if (basil_storage_get('blog_template') > 0)
				$classes[] = 'blog_template';
		}
		
		if (basil_sidebar_present()) {
			$classes[] = 'sidebar_show sidebar_' . esc_attr(basil_get_theme_option('sidebar_position')) ;
		} else {
			$classes[] = 'sidebar_hide';
			if (basil_is_on(basil_get_theme_option('expand_content')))
				$classes[] = 'expand_content';
		}
		
		if (basil_is_on(basil_get_theme_option('remove_margins')))
			$classes[] = 'remove_margins';

		$classes[] = 'header_style_' . esc_attr(basil_get_theme_option("header_style"));
		$classes[] = 'header_position_' . esc_attr(basil_get_theme_option("header_position"));

		$menu_style= basil_get_theme_option("menu_style");
		$classes[] = 'menu_style_' . esc_attr($menu_style) . (in_array($menu_style, array('left', 'right'))	? ' menu_style_side' : '');
		$classes[] = 'no_layout';
		
		return $classes;
	}
}

// Load inline styles
if ( !function_exists( 'basil_wp_footer' ) ) {
	function basil_wp_footer() {
		// Get inline styles from storage
		if (($css = basil_storage_get('inline_styles')) != '') {
			wp_enqueue_style(  'basil-inline-styles',  basil_get_file_url('css/__inline.css') );
			wp_add_inline_style( 'basil-inline-styles', $css );
		}
	}
}


//-------------------------------------------------------
//-- Sidebars and widgets
//-------------------------------------------------------

// Register widgetized areas
if ( !function_exists('basil_register_sidebars') ) {
	function basil_register_sidebars() {
		$sidebars = basil_get_sidebars();
		if (is_array($sidebars) && count($sidebars) > 0) {
			foreach ($sidebars as $id=>$sb) {
				register_sidebar( array(
					'name'          => $sb['name'],
					'description'   => $sb['description'],
					'id'            => $id,
					'before_widget' => '<aside id="%1$s" class="widget %2$s">',
					'after_widget'  => '</aside>',
					'before_title'  => '<h5 class="widget_title">',
					'after_title'   => '</h5>'
					)
				);
			}
		}
	}
}

// Return theme specific widgetized areas
if ( !function_exists('basil_get_sidebars') ) {
	function basil_get_sidebars() {
		$list = apply_filters('basil_filter_list_sidebars', array(
			'sidebar_widgets'		=> array(
				'name' => esc_html__('Sidebar Widgets', 'basil'),
				'description' => esc_html__('Widgets to be shown on the main sidebar', 'basil')
				),
			'above_page_widgets'	=> array(
				'name' => esc_html__('Above Page Widgets', 'basil'),
				'description' => esc_html__('Widgets to be shown below the header, but above the content and sidebar', 'basil')
				),
			'below_page_widgets' 	=> array(
				'name' => esc_html__('Below Page Widgets', 'basil'),
				'description' => esc_html__('Widgets to be shown below the content and sidebar, but above the footer', 'basil')
				),
			'footer_widgets'		=> array(
				'name' => esc_html__('Footer Widgets', 'basil'),
				'description' => esc_html__('Widgets to be shown at the bottom of the page (in the page footer area)', 'basil')
				)
			)
		);
		$custom_sidebars_number = max(0, min(10, basil_get_theme_setting('custom_sidebars')));
		if (count((array)$custom_sidebars_number) > 0) {
			for ($i=1; $i <= $custom_sidebars_number; $i++) {
				$list['custom_widgets_'.intval($i)] = array(
					'name' => sprintf(esc_html__('Custom Widgets %d', 'basil'), $i),
					'description' => esc_html__('An arbitrary set of widgets. Can be shown in any area of the site', 'basil')
					);
			}
		}
		return $list;
	}
}


//-------------------------------------------------------
//-- Theme fonts
//-------------------------------------------------------

// Return links for all theme fonts
if ( !function_exists('basil_theme_fonts_links') ) {
	function basil_theme_fonts_links() {
		$links = array();
		
		/*
		Translators: If there are characters in your language that are not supported
		by chosen font(s), translate this to 'off'. Do not translate into your own language.
		*/
		$google_fonts_enabled = ( 'off' !== esc_html_x( 'on', 'Google fonts: on or off', 'basil' ) );
		$custom_fonts_enabled = ( 'off' !== esc_html_x( 'on', 'Custom fonts (included in the theme): on or off', 'basil' ) );
		
		if ( ($google_fonts_enabled || $custom_fonts_enabled) && !basil_storage_empty('load_fonts') ) {
			$load_fonts = basil_storage_get('load_fonts');
			if (is_array($load_fonts) && count($load_fonts) > 0) {
				$google_fonts = '';
				foreach ($load_fonts as $font) {
					$slug = basil_get_load_fonts_slug($font['name']);
					$url  = basil_get_file_url( sprintf('css/font-face/%s/stylesheet.css', $slug));
					if ($url != '') {
						if ($custom_fonts_enabled) {
							$links[$slug] = $url;
						}
					} else {
						if ($google_fonts_enabled) {
							$google_fonts .= ($google_fonts ? '|' : '') 
							. str_replace(' ', '+', $font['name'])
							. ':' 
							. (empty($font['styles']) ? '400,400italic,700,700italic' : $font['styles']);
						}
					}
				}
				if ($google_fonts && $google_fonts_enabled) {
					$links['google_fonts'] = sprintf('%s://fonts.googleapis.com/css?family=%s&subset=%s', basil_get_protocol(), $google_fonts, basil_get_theme_option('load_fonts_subset'));
				}
			}
		}
		return $links;
	}
}

// Return links for WP Editor
if ( !function_exists('basil_theme_fonts_for_editor') ) {
	function basil_theme_fonts_for_editor() {
		$links = array_values(basil_theme_fonts_links());
		if (is_array($links) && count($links) > 0) {
			for ($i=0; $i<count($links); $i++) {
				$links[$i] = str_replace(',', '%2C', $links[$i]);
			}
		}
		return $links;
	}
}


//-------------------------------------------------------
//-- The Excerpt
//-------------------------------------------------------
if ( !function_exists('basil_excerpt_length') ) {
	function basil_excerpt_length( $length ) {
		return max(1, basil_get_theme_setting('max_excerpt_length'));
	}
}

if ( !function_exists('basil_excerpt_more') ) {
	function basil_excerpt_more( $more ) {
		return '&hellip;';
	}
}


//------------------------------------------------------------------------
// One-click import support
//------------------------------------------------------------------------

// Set theme specific importer options
if ( !function_exists( 'basil_importer_set_options' ) ) {
	function basil_importer_set_options($options=array()) {
		if (is_array($options)) {
			// Prepare demo data
			$options['demo_url'] = esc_url(basil_get_protocol() . '://demofiles.axiomthemes.com/basil/');
			// Required plugins
			$options['required_plugins'] = basil_storage_get('required_plugins');
			// Default demo
			$options['files']['default']['title'] = esc_html__('Basil Demo', 'basil');
			$options['files']['default']['domain_dev'] = esc_url(basil_get_protocol() . '://basil.axiomthemes.com');		// Developers domain
			$options['files']['default']['domain_demo']= esc_url(basil_get_protocol() . '://basil.axiomthemes.com');		// Demo-site domain
		}
		return $options;
	}
}


// Add checkbox with "I agree ..."
if ( ! function_exists( 'basil_comment_form_agree' ) ) {
    add_filter('comment_form_fields', 'basil_comment_form_agree', 11);
    function basil_comment_form_agree( $comment_fields ) {
        $privacy_text = basil_get_privacy_text();
        if ( ! empty( $privacy_text ) ) {
            $comment_fields['i_agree_privacy_policy'] = basil_single_comments_field(
                array(
                    'form_style'        => 'default',
                    'field_type'        => 'checkbox',
                    'field_req'         => '',
                    'field_icon'        => '',
                    'field_value'       => '1',
                    'field_name'        => 'i_agree_privacy_policy',
                    'field_title'       => $privacy_text,
                )
            );
        }
        return $comment_fields;
    }
}





//-------------------------------------------------------
//-- Include theme (or child) PHP-files
//-------------------------------------------------------

require_once trailingslashit( get_template_directory() ) . 'includes/utils.php';
require_once trailingslashit( get_template_directory() ) . 'includes/storage.php';
require_once trailingslashit( get_template_directory() ) . 'includes/lists.php';
require_once trailingslashit( get_template_directory() ) . 'includes/wp.php';

if (is_admin()) {
	require_once trailingslashit( get_template_directory() ) . 'includes/tgmpa/class-tgm-plugin-activation.php';
	require_once trailingslashit( get_template_directory() ) . 'includes/admin.php';
}

require_once trailingslashit( get_template_directory() ) . 'theme-options/theme.customizer.php';

require_once trailingslashit( get_template_directory() ) . 'theme-specific/trx_addons.php';

require_once trailingslashit( get_template_directory() ) . 'includes/theme.tags.php';
require_once trailingslashit( get_template_directory() ) . 'includes/theme.hovers/theme.hovers.php';


// Plugins support
if (is_array($BASIL_STORAGE['required_plugins']) && count($BASIL_STORAGE['required_plugins']) > 0) {
	foreach ($BASIL_STORAGE['required_plugins'] as $plugin_slug) {
		$plugin_slug = basil_esc($plugin_slug);
		$plugin_path = trailingslashit( get_template_directory() ) . sprintf('plugins/%s/%s.php', $plugin_slug, $plugin_slug);
		if (file_exists($plugin_path)) { require_once $plugin_path; }
	}
}
?>