<?php
/**
 * The template for homepage posts with "Portfolio" style
 *
 * @package WordPress
 * @subpackage BASIL
 * @since BASIL 1.0
 */

basil_storage_set('blog_archive', true);

// Load scripts for both 'Gallery' and 'Portfolio' layouts!
wp_enqueue_script( 'classie', basil_get_file_url('js/theme.gallery/classie.min.js'), array(), null, true );
wp_enqueue_script( 'imagesloaded', basil_get_file_url('js/theme.gallery/imagesloaded.min.js'), array(), null, true );
wp_enqueue_script( 'masonry', basil_get_file_url('js/theme.gallery/masonry.min.js'), array(), null, true );
wp_enqueue_script( 'basil-gallery-script', basil_get_file_url('js/theme.gallery/theme.gallery.js'), array(), null, true );

get_header(); 

if (have_posts()) {

	echo get_query_var('blog_archive_start');

	$basil_stickies = is_home() ? get_option( 'sticky_posts' ) : false;
	$basil_sticky_out = is_array($basil_stickies) && count($basil_stickies) > 0 && get_query_var( 'paged' ) < 1;
	
	// Show filters
	$basil_cat = basil_get_theme_option('parent_cat');
	$basil_post_type = basil_get_theme_option('post_type');
	$basil_taxonomy = basil_get_post_type_taxonomy($basil_post_type);
	$basil_show_filters = basil_get_theme_option('show_filters');
	$basil_tabs = array();
	if (!basil_is_off($basil_show_filters)) {
		$basil_args = array(
			'type'			=> $basil_post_type,
			'child_of'		=> $basil_cat,
			'orderby'		=> 'name',
			'order'			=> 'ASC',
			'hide_empty'	=> 1,
			'hierarchical'	=> 0,
			'exclude'		=> '',
			'include'		=> '',
			'number'		=> '',
			'taxonomy'		=> $basil_taxonomy,
			'pad_counts'	=> false
		);
		$basil_portfolio_list = get_terms($basil_args);
		if (is_array($basil_portfolio_list) && count($basil_portfolio_list) > 0) {
			$basil_tabs[$basil_cat] = esc_html__('All', 'basil');
			foreach ($basil_portfolio_list as $basil_term) {
				if (isset($basil_term->term_id)) $basil_tabs[$basil_term->term_id] = $basil_term->name;
			}
		}
	}
	if (count($basil_tabs) > 0) {
		$basil_portfolio_filters_ajax = true;
		$basil_portfolio_filters_active = $basil_cat;
		$basil_portfolio_filters_id = 'portfolio_filters';
		if (!is_customize_preview())
			wp_enqueue_script('jquery-ui-tabs', false, array('jquery', 'jquery-ui-core'), null, true);
		?>
		<div class="portfolio_filters basil_tabs basil_tabs_ajax">
			<ul class="portfolio_titles basil_tabs_titles">
				<?php
				foreach ($basil_tabs as $basil_id=>$basil_title) {
					?><li><a href="<?php echo esc_url(basil_get_hash_link(sprintf('#%s_%s_content', $basil_portfolio_filters_id, $basil_id))); ?>" data-tab="<?php echo esc_attr($basil_id); ?>"><?php echo esc_html($basil_title); ?></a></li><?php
				}
				?>
			</ul>
			<?php
			$basil_ppp = basil_get_theme_option('posts_per_page');
			if (basil_is_inherit($basil_ppp)) $basil_ppp = '';
			foreach ($basil_tabs as $basil_id=>$basil_title) {
				$basil_portfolio_need_content = $basil_id==$basil_portfolio_filters_active || !$basil_portfolio_filters_ajax;
				?>
				<div id="<?php echo esc_attr(sprintf('%s_%s_content', $basil_portfolio_filters_id, $basil_id)); ?>"
					class="portfolio_content basil_tabs_content"
					data-blog-template="<?php echo esc_attr(basil_storage_get('blog_template')); ?>"
					data-blog-style="<?php echo esc_attr(basil_get_theme_option('blog_style')); ?>"
					data-posts-per-page="<?php echo esc_attr($basil_ppp); ?>"
					data-post-type="<?php echo esc_attr($basil_post_type); ?>"
					data-taxonomy="<?php echo esc_attr($basil_taxonomy); ?>"
					data-cat="<?php echo esc_attr($basil_id); ?>"
					data-parent-cat="<?php echo esc_attr($basil_cat); ?>"
					data-need-content="<?php echo (false===$basil_portfolio_need_content ? 'true' : 'false'); ?>"
				>
					<?php
					if ($basil_portfolio_need_content) 
						basil_show_portfolio_posts(array(
							'cat' => $basil_id,
							'parent_cat' => $basil_cat,
							'taxonomy' => $basil_taxonomy,
							'post_type' => $basil_post_type,
							'page' => 1,
							'sticky' => $basil_sticky_out
							)
						);
					?>
				</div>
				<?php
			}
			?>
		</div>
		<?php
	} else {
		basil_show_portfolio_posts(array(
			'cat' => $basil_cat,
			'parent_cat' => $basil_cat,
			'taxonomy' => $basil_taxonomy,
			'post_type' => $basil_post_type,
			'page' => 1,
			'sticky' => $basil_sticky_out
			)
		);
	}

	echo get_query_var('blog_archive_end');

} else {

	if ( is_search() )
		get_template_part( 'content', 'none-search' );
	else
		get_template_part( 'content', 'none-archive' );

}

get_footer();
?>