<?php
/* Mail Chimp support functions
------------------------------------------------------------------------------- */

// Theme init priorities:
// 9 - register other filters (for installer, etc.)
if (!function_exists('basil_mailchimp_theme_setup9')) {
	add_action( 'after_setup_theme', 'basil_mailchimp_theme_setup9', 9 );
	function basil_mailchimp_theme_setup9() {
		if (basil_exists_mailchimp()) {
			add_action( 'wp_enqueue_scripts',							'basil_mailchimp_frontend_scripts', 1100 );
			add_filter( 'basil_filter_merge_styles',					'basil_mailchimp_merge_styles');
			add_filter( 'basil_filter_get_css',						'basil_mailchimp_get_css', 10, 4);
		}
		if (is_admin()) {
			add_filter( 'basil_filter_tgmpa_required_plugins',		'basil_mailchimp_tgmpa_required_plugins' );
		}
	}
}

// Check if plugin installed and activated
if ( !function_exists( 'basil_exists_mailchimp' ) ) {
	function basil_exists_mailchimp() {
		return function_exists('__mc4wp_load_plugin') || defined('MC4WP_VERSION');
	}
}

// Filter to add in the required plugins list
if ( !function_exists( 'basil_mailchimp_tgmpa_required_plugins' ) ) {
	function basil_mailchimp_tgmpa_required_plugins($list=array()) {
		if (in_array('mailchimp-for-wp', basil_storage_get('required_plugins')))
			$list[] = array(
				'name' 		=> esc_html__('MailChimp for WP', 'basil'),
				'slug' 		=> 'mailchimp-for-wp',
				'required' 	=> false
			);
		return $list;
	}
}



// Custom styles and scripts
//------------------------------------------------------------------------

// Enqueue custom styles
if ( !function_exists( 'basil_mailchimp_frontend_scripts' ) ) {
	function basil_mailchimp_frontend_scripts() {
		if (basil_exists_mailchimp()) {
			if (basil_is_on(basil_get_theme_option('debug_mode')) && file_exists(basil_get_file_dir('plugins/mailchimp-for-wp/mailchimp-for-wp.css')))
				wp_enqueue_style( 'basil-mailchimp-for-wp',  basil_get_file_url('plugins/mailchimp-for-wp/mailchimp-for-wp.css'), array(), null );
		}
	}
}
	
// Merge custom styles
if ( !function_exists( 'basil_mailchimp_merge_styles' ) ) {
	function basil_mailchimp_merge_styles($list) {
		$list[] = 'plugins/mailchimp-for-wp/mailchimp-for-wp.css';
		return $list;
	}
}

// Add css styles into global CSS stylesheet
if (!function_exists('basil_mailchimp_get_css')) {
	function basil_mailchimp_get_css($css, $colors, $fonts, $scheme='') {
		
		if (isset($css['fonts']) && $fonts) {
			$css['fonts'] .= <<<CSS

CSS;
		}
		
		if (isset($css['colors']) && $colors) {
			$css['colors'] .= <<<CSS

.mc4wp-form input[type="email"] {
	background-color: {$colors['alter_bg_color']};
}
.mc4wp-form input[type="submit"] {
	background-color: {$colors['alter_link']};
	color: {$colors['inverse_text']};
}
.mc4wp-form input[type="submit"]:hover {
	background-color: transparent;
	color: {$colors['text_link']};
	border-color:{$colors['text_link']};

}

CSS;
		}

		return $css;
	}
}
?>