<?php
/* Theme-specific action to configure ThemeREX Addons components
------------------------------------------------------------------------------- */


add_action( 'comment_post', 'basil_save_additional_fields' );
add_filter( 'comment_form_fields', 'basil_wpb_move_comment_field_to_bottom' );
add_action( 'add_overrides_comment', 'basil_add_reviews_override_options_admin' );
add_action( 'edit_comment', 'basil_reviews_edit_metafields' );
add_filter( 'preprocess_comment', 'basil_verify_reviews_meta_data' );

// Theme init priorities:
// 1 - register filters, that add/remove lists items for the Theme Options
if (!function_exists('basil_trx_addons_theme_specific_setup')) {
	add_action( 'after_setup_theme', 'basil_trx_addons_theme_specific_setup' );
	function basil_trx_addons_theme_specific_setup() {
		if (basil_exists_trx_addons()) {
			add_filter( 'trx_addons_filter_default_layouts',	'basil_trx_addons_theme_specific_default_layouts');
		}
	}
}



//Meke manipulation with review-form for course
//Replace textarea to down for standart output
function basil_wpb_move_comment_field_to_bottom( $fields ) {
	$comment_field = $fields['comment'];
	unset( $fields['comment'] );
	$fields['comment'] = $comment_field;
	return $fields;
}

//Save additional comment meta 
function basil_save_additional_fields($comment_id){
	if (isset($_POST['location']) && $_POST['location'] != ''){
		add_comment_meta( $comment_id, 'location', $_POST['location']);
	}
	if ( isset( $_POST['rating']) && $_POST['rating'] != '' ){
		add_comment_meta( $comment_id, 'rating', $_POST['rating'] );
	}
}

// Update comment meta data from comment admin pandel screen 
function basil_reviews_edit_metafields( $comment_id ) {
	if( ! isset( $_POST['extend_comment_update'] ) || ! wp_verify_nonce( $_POST['extend_comment_update'], 'extend_comment_update' ) ) return;

	if ( ( isset( $_POST['location'] ) ) && ( $_POST['location'] != '') ):
		$location = wp_filter_nohtml_kses($_POST['location']);
	update_comment_meta( $comment_id, 'location', $location );
	else :
		delete_comment_meta( $comment_id, 'location');
	endif;

	if ( ( isset( $_POST['rating'] ) ) && ( $_POST['rating'] != '') ):
		$rating = wp_filter_nohtml_kses($_POST['rating']);
	update_comment_meta( $comment_id, 'rating', $rating );
	else :
		delete_comment_meta( $comment_id, 'rating');
	endif;

}



function basil_verify_reviews_meta_data( $commentdata ) {
if ( !isset( $_POST['rating']) && isset( $_POST['post_type']) )
  wp_die( esc_html__( 'Error: You did not add a rating. Hit the Back button on your Web browser and resubmit your review with a rating.', 'basil' ) );
  return $commentdata;
}

function basil_courses_reviews_list(){
	$reviews = get_comments(array('post_id' => get_the_ID(), 'status'=>'approve'));
	$mult = basil_get_retina_multiplier();
	global $wpdb;
	$output = '<div class="reviews_wrap">
	<ul class="reviews_list">';
		foreach ($reviews as $review) {
			$count = $wpdb->get_var($wpdb->prepare("SELECT COUNT(*) FROM $wpdb->users WHERE ID = %d", $review->user_id));
			$location = get_comment_meta($review->comment_ID, 'location', true);
			$user_reviews = get_comments(array('user_id'=>$review->user_id, 'count'=> true, 'post_type'=>'cpt_courses'));
			$rating = get_comment_meta($review->comment_ID, 'rating', true);
			if($review->comment_type != 'pingback' && $review->comment_type != 'trackback'){
				$output .= '<li id="review-'. $review->comment_ID.'" class="review_item_content">'
				.'<div class="review_author_wrap">'
					.'<div class="review_author_avatar">'. get_avatar( $review, 70*$mult ).'</div>'
					.'<h6 class="review_author">'.$review->comment_author.'</h6>'
					. ($count > 0 ? '<span class="review_author_counts_review icon-star">'. esc_attr($user_reviews) .' '.($user_reviews != 1 ? esc_html__('Reviews','basil') : esc_html__('Review','basil'))  .'</span>' : '')
					.(!empty($location) ? '<span class="review_author_location icon-location">'.esc_attr($location).'</span>' :'')
				.'</div><div class="review_content"><div class="review_info">';
				if($rating>= 1) {
					$output .='<span class="rewiews_rating">';
					for($i=0; $i < 5; $i++) { 
						$output .= ($rating >$i ? '<span class="icon-star"></span>':'<span class="icon-star-empty"></span>');
					};
					$output .='</span>';
				}
				$output .= '<span class="review_date">'. get_comment_date('j F, Y', $review ->comment_ID).'</span>
			</div><div class="review_text">'. $review ->comment_content.'</div></li>';
	}
}
$output .= '</ul></div>';
return $output;
}


function basil_return_course_meta(){
	$reviews = get_comments(array('post_id'=>get_the_ID(), 'status'=>'approve'));
	$count=0;
	foreach ($reviews as $review) {
		$count += get_comment_meta($review->comment_ID, 'rating', true);
	}
	$reviews_count = count($reviews);
	$rez = round($count/$reviews_count, 2);
	$rating = '';
	for($i=0; $i < 5; $i++) { 
		$rating .= (floor($rez) > $i ? '<span class="icon-star"></span>':'<span class="icon-star-empty"></span>');
	};
	echo '<div class="course_item_meta">
		<span class="item_meta_rating">'.($rating).'<span class="rating_label">'.esc_attr($rez).'</span>'.'</span><span class="item_meta_count_review">'
		.$reviews_count.' '.($reviews_count != 1 ? esc_html__('Reviews','basil') : esc_html__('Review','basil'))
		.'</span>
	</div>';
	
}

?>